docs.rs failed to build tauri-plugin-persistence-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
tauri-plugin-persistence-0.2.1
tauri-plugin-persistence
A wrapper plugin for several persistence backends, focused on managing complex project folders with less boilerplate.
Installation
# Install cargo dependency
# Install JS dependency
Setup
The plugin must be initialized in Rust. A basic example follows:
Usage
The plugin's functions can be accessed in Rust from app.persistence(), or in the frontend (see the example).