pub struct Persistence<R: Runtime>(/* private fields */);Expand description
Access to the persistence APIs.
Implementations
Sourceimpl<R: Runtime> Persistence<R>
impl<R: Runtime> Persistence<R>
Sourcepub async fn open_context(
&self,
name: impl AsRef<str>,
path: impl AsRef<str>,
) -> Result<Context<R>>
pub async fn open_context( &self, name: impl AsRef<str>, path: impl AsRef<str>, ) -> Result<Context<R>>
Opens a context at a path, or returns the existing context if it’s already open at that path. Attmepting to open an existing context at a new path will fail.
Sourcepub async fn aliased_context(&self, name: impl AsRef<str>) -> Result<Context<R>>
pub async fn aliased_context(&self, name: impl AsRef<str>) -> Result<Context<R>>
Returns an already-open context
Sourcepub async fn context(&self, context: ContextSpecifier) -> Result<Context<R>>
pub async fn context(&self, context: ContextSpecifier) -> Result<Context<R>>
Returns a context based on a ContextSpecifier. This abstracts Persistence::open_context and Persistence::aliased_context
Sourcepub async fn database(
&self,
context: ContextSpecifier,
database: DatabaseSpecifier,
) -> Result<Database<R>>
pub async fn database( &self, context: ContextSpecifier, database: DatabaseSpecifier, ) -> Result<Database<R>>
Returns a database based on a ContextSpecifier and a DatabaseSpecifier
Sourcepub async fn file_handle(
&self,
context: ContextSpecifier,
file_handle: FileHandleSpecifier,
) -> Result<FileHandle<R>>
pub async fn file_handle( &self, context: ContextSpecifier, file_handle: FileHandleSpecifier, ) -> Result<FileHandle<R>>
Returns a file handle based on a ContextSpecifier and a FileHandleSpecifier
Sourcepub async fn transaction(
&self,
context: ContextSpecifier,
database: DatabaseSpecifier,
transaction: Uuid,
) -> Result<Transaction<R>>
pub async fn transaction( &self, context: ContextSpecifier, database: DatabaseSpecifier, transaction: Uuid, ) -> Result<Transaction<R>>
Returns an open transaction based on a ContextSpecifier and a DatabaseSpecifier, as well as the transaction ID
Sourcepub async fn collection<T: Serialize + DeserializeOwned + Sync + Send>(
&self,
context: ContextSpecifier,
database: DatabaseSpecifier,
collection: CollectionSpecifier,
) -> Result<Collection<T, R>>
pub async fn collection<T: Serialize + DeserializeOwned + Sync + Send>( &self, context: ContextSpecifier, database: DatabaseSpecifier, collection: CollectionSpecifier, ) -> Result<Collection<T, R>>
Returns a collection based on a ContextSpecifier, DatabaseSpecifier, and a CollectionSpecifier
Sourcepub async fn close_context(&self, context: ContextSpecifier) -> Result<()>
pub async fn close_context(&self, context: ContextSpecifier) -> Result<()>
Closes a context based on a ContextSpecifier