Exports a reference to various utility types.
Structs
- Collection
Info - A model containing serializable information about a crate::Collection
- Context
Info - A model containing serializable information about a crate::Context
- Database
Info - A model containing serializable information about a crate::Database
- File
Handle Info - A model containing serializable information about a crate::FileHandle
- Json
Bson - Specta version of bson::Bson
- Json
Document - Specta version of bson::Document
- Path
Information - General info about a path
- Path
Metadata - File or folder metadata
- Update
Result - Serializable version of polodb_core::results::UpdateResult
Enums
- Collection
Specifier - A model used to specify a collection
- Context
Specifier - A model used to specify an existing or closed context
- Database
Specifier - A model used to specify an existing or closed database
- File
Handle Specifier - A model used to specify an existing or closed file handle
- Operation
Count - Whether to do one operation or multiple (in a database context)
- Path
File Type - Description of the type of a file/directory/symlink