tauri-plugin-persistence 0.1.0

A wrapper plugin for several persistence backends, focused on managing complex project folders with less boilerplate.
docs.rs failed to build tauri-plugin-persistence-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: tauri-plugin-persistence-0.2.1

tauri-plugin-persistence

A wrapper plugin for several persistence backends, focused on managing complex project folders with less boilerplate.

Installation

# Install cargo dependency
cargo add tauri-plugin-persistence

# Install JS dependency
npm install tauri-plugin-persistence-api

Setup

The plugin must be initialized in Rust. A basic example follows:

pub fn run() {
    tauri::Builder::default()
        .plugin(tauri_plugin_persistence::init())
        .run(tauri::generate_context!())
        .expect("error while running tauri application");
}

Usage

The plugin's functions can be accessed in Rust from app.persistence(), or in the frontend (see the example).